﻿using System;
using System.Windows.Media.Imaging;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace post8237
{
    public class MyOverlay : Overlay
    {
        private FeatureSourceMarkerOverlay markerOverlay1;
        private FeatureSourceMarkerOverlay markerOverlay2;

        public MyOverlay()
            : base()
        {
            markerOverlay1 = new FeatureSourceMarkerOverlay(new ShapeFileFeatureSource(@"C:\Program Files\ThinkGeo\Map Suite Desktop Full Edition 3.0\Samples\SampleData\Data\WorldCapitals.shp"));
            markerOverlay2 = new FeatureSourceMarkerOverlay(new ShapeFileFeatureSource(@"C:\Program Files\ThinkGeo\Map Suite Desktop Full Edition 3.0\Samples\SampleData\Data\MajorCities.shp"));

            SetStyle();

            OverlayCanvas.Children.Add(markerOverlay1.OverlayCanvas);
            OverlayCanvas.Children.Add(markerOverlay2.OverlayCanvas);
        }

        private void SetStyle()
        {
            markerOverlay1.ZoomLevelSet.ZoomLevel01.DefaultPointMarkerStyle.ImageSource = new BitmapImage(new Uri("/Images/markerIcon.png", UriKind.RelativeOrAbsolute));
            markerOverlay1.ZoomLevelSet.ZoomLevel01.DefaultPointMarkerStyle.Width = 20;
            markerOverlay1.ZoomLevelSet.ZoomLevel01.DefaultPointMarkerStyle.Height = 34;
            markerOverlay1.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            markerOverlay2.ZoomLevelSet.ZoomLevel01.DefaultPointMarkerStyle.ImageSource = new BitmapImage(new Uri("/Images/about.png", UriKind.RelativeOrAbsolute));
            markerOverlay2.ZoomLevelSet.ZoomLevel01.DefaultPointMarkerStyle.Width = 26;
            markerOverlay2.ZoomLevelSet.ZoomLevel01.DefaultPointMarkerStyle.Height = 26;
            markerOverlay2.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
        }

        public Projection Projection
        {
            set
            {
                markerOverlay1.FeatureSource.Projection = value;
                markerOverlay2.FeatureSource.Projection = value;
            }
        }

        protected override void DrawCore(RectangleShape targetExtent, RefreshType refreshType)
        {
            markerOverlay1.MapArguments = MapArguments;
            markerOverlay2.MapArguments = MapArguments;

            markerOverlay1.Draw(targetExtent, refreshType);
            markerOverlay2.Draw(targetExtent, refreshType);
        }

        protected override void PanToCore(RectangleShape targetExtent)
        {
            markerOverlay1.MapArguments = this.MapArguments;
            markerOverlay2.MapArguments = this.MapArguments;

            markerOverlay1.PanTo(targetExtent);
            markerOverlay2.PanTo(targetExtent);
        }

        protected override RectangleShape GetBoundingBoxCore()
        {
            RectangleShape[] rects = new RectangleShape[] { markerOverlay1.GetBoundingBox(), markerOverlay2.GetBoundingBox() };
            return ExtentHelper.GetBoundingBoxOfItems(rects);
        }
    }
}
